export interface ArticleMessage {
    DOI: string;
    issue: number;
    title: string;
    author: Array<{ family: string; given: string }>;
    "container-title-short": string;
    "container-title": string;
    abstract: string;
    published: {
        "date-parts": string[];
    };
}


export interface Article {
    DOI: string
    title: string
    subtitle: string
    containerTitle: string
    abstract: string
    year: string
    href: string
    target: string
    prependIcon: string
}
export interface RawArticle {
    message: ArticleMessage

}



export function useFetchArticle(doi: string) {

    const article = ref<Article | null>(null)
    const pending = ref(false)
    const doiBaseUrl = ref(new URL("https://doi.org/"));
    const url = ref(new URL(`/works/${doi}`, " https://api.crossref.org/").href);
    console.log("dans useFetchArticle")
    console.log(url.value)
    watchEffect(async () => {
        console.log("dans watch effect")
        article.value = null
        const { data, pending: pendingUseFetch, error, refresh } = await useFetch<RawArticle>(toValue(url), {
        })
        console.log(data)
        if (data.value?.message) {
            const {
                DOI,
                title,
                "container-title-short": cts,
                "container-title": ct,
                abstract,
                published,
                author,
                ...rest
            } = data.value.message;
            let sanitizedAbstract = abstract
            console.log(DOI)
            if (sanitizedAbstract) {
                sanitizedAbstract = /\<jats\:p\>(.*)\<\/jats\:p\>/.exec(sanitizedAbstract)?.[1] ?? ''
            }
            article.value = {
                DOI,
                title: title[0],
                subtitle: toAuthorsString(author || []),
                containerTitle: cts?.length > 0 ? cts[0] : ct?.length > 0 ? ct[0] : "",
                abstract: sanitizedAbstract,
                year: published["date-parts"][0][0],
                href: getReferenceUrl(DOI),
                target: "_blank",
                prependIcon: "mdi-newspaper-variant-outline",
            }
            console.log(article.value)
        }
        pending.value = pendingUseFetch.value


    })
    function toAuthorsString(authors: Array<{ family: string; given: string }>) {
        return authors
            .map((curr) => {
                return `${curr.family} ${curr.given}`;
            })
            .join(", ");
    }

    function getReferenceUrl(doi: string) {
        return new URL(doi, doiBaseUrl.value).href;
    }
    return { article, pending }
}